@@ -20,6 +20,11 @@ class MeasurementManager(object):
         self.genomes = {}
         self.measurements = []
         self.emd_endpoint = None
+        self.stats = {
+            "getRows": {},
+            "getValues": {},
+            "search": {}
+        }
 
     def import_dbm(self, dbConn):
         """Import measurements from a database.The database 
@@ -267,8 +272,4 @@ class MeasurementManager(object):
         except Exception as e:
             return "", "Error inserting new measurements from emd api {}".format(e)
 
-        return new_records, ""
-        
-
-
-        
\ No newline at end of file
+        return new_records, ""
\ No newline at end of file
